@@ -775,7 +775,7 @@ pcheck.spatial <- function(layer=NULL, dsn=NULL, sql=NA, fmt=NULL, tabnm=NULL,
 
   ## Check layer - if sf object
   if (!is.null(layer)) {
-    if (length(class(layer) == "list") && class(layer) == "list") {
+    if (length(inherits(layer, "list")) && inherits(layer, "list")) {
       if (length(layer) != 1) {
         stop("invalid layer")
       } else {
